@@ -6,7 +6,7 @@ use vars qw($VERSION @ISA);
 use DynaLoader;
 
 @ISA = qw(DynaLoader);
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 __PACKAGE__->bootstrap($VERSION);
 
@@ -25,8 +25,8 @@ Win32::Symlink - Symlink support on Windows
 
 =head1 VERSION
 
-This document describes version 0.05 of Win32::Symlink, released
-October 24, 2011.
+This document describes version 0.06 of Win32::Symlink, released
+April 13, 2015.
 
 =head1 SYNOPSIS
 
@@ -49,7 +49,7 @@ L<Win32::Hardlink>
 
 =head1 AUTHORS
 
-唐鳳 E<lt>cpan@audreyt.orgE<gt>
+Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 =head1 CC0 1.0 Universal
 
